/*###############################################################################
## OpenBTrainer project
##
## Copyright (C) 2009 Jose Luis Falcón Ramírez  jose.falconra@alum.uca.es
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###############################################################################*/

#ifndef _MINIJUEGO_H
#define	_MINIJUEGO_H

/**Clase minijuego
 * Se incluyen los juegos memorion y diferencias
 */
class minijuego {
public:
    /**Constructor de la clase minijuego, en el generamos una semilla aleatoria que nos servirá en los distintos minijuegos*/
    minijuego();
    /**Inicia el juego del memorión, nos devuelve la puntuación obtenida que vendrá dada por el tiempo que hemos empleado para terminar
     * los tres niveles*/
    Uint32 memorion(SDL_Surface *pantalla);
    /**Inicia el juego de las diferencias, nos devuelve la puntuacion obtenida que vendrá dada por el tiempo que hemos empleado para
     * terminar los fallos de la imágen*/
    Uint32 diferencias(SDL_Surface *pantalla);
    virtual ~minijuego();
private:
    /** @brief estructura de datos memorion
     *
     * Nos sirve para almacenar los datos de la matriz de cartas y el número de cartas que disponemos en cada nivel
     */
    typedef struct{
        Uint32 matriz[8][3];
        Uint32 numCartas;
    }datosmemorion;
    /** @brief estructura de datos de carta levantada
     *
     * Nos sirve para almacenar la posicion dentro de la matriz de la primera carta que hemos levantado en cada turno
     */
    typedef struct{
        Uint32 x;
        Uint32 y;
    }tipolevantada;
    /**Completa la tarea de dar la vuelta a una carta y mostrar el verdadero valor de la carta
     * @param pantalla: recibe la superficie de la pantalla inicializada
     * @param rectcarta: recibe el SDL_Rect con la posicion donde se dibujará la carta en la pantalla
     * @param datosmemorion: datos del juego actual
     * @param x: posicion en x dentro de la matriz que nos indica la carta a levantar
     * @param y: posicion en y dentro de la matriz que nos indica la carta a levantar
     */
    void voltear_carta(SDL_Surface* pantalla, SDL_Rect rectcarta, datosmemorion datos, Uint32 x, Uint32 y);
    /**Sirve para volver la mesa a su estado inicial, pero sin las cartas que han sido eliminadas
     * @param pantalla: recibe la superficie de la pantalla inicializada
     * @param datos: datos del juego actual para ver que cartas han sido eliminadas
     */
    void dibujar_mesa(SDL_Surface* pantalla, datosmemorion datos);
    /**Nos ayuda a comprobar si las dos cartas levantadas son iguales. Si no son iguales
     * se llamará a dibujar mesa y sin cambios, en caso contrario se escribirá un 0 en las dos posiciones de la matriz que
     * hemos descubierto, luego llamaremos de nuevo a dibujar mesa
     * @param pantalla: recibe la superficie de la pantalla inicializada
     * @param *datos: recibe un puntero a los datos actuales del juego
     * @param carta_levantada: recibe la posicion x e y de la carta que hemos levantado en primer lugar
     * @param x: recibe la posicion en x en la matriz de la carta que hemos levantado en segundo lugar
     * @param y: recibe la posicion en y en la matriz de la carta que hemos levantado en segundo lugar
     */
    Uint32 comprobacion_parejas(SDL_Surface* pantalla, datosmemorion *datos, tipolevantada carta_levantada, Uint32 x, Uint32 y, Uint32 *cartasEmparejadas);
     typedef struct{
        Uint32 x[10];
        Uint32 y[10];
        Uint32 cuadro[10];
        bool marcado[10];
        Uint32 numdif;
    }tipoerrores;

    void dibujaescenario_diferencias(SDL_Surface *pantalla, SDL_Surface *fig1, SDL_Surface *fig2, SDL_Surface* texto);
};

#endif /*_MINIJUEGO_H*/

