/*###############################################################################
## OpenBTrainer project
##
## Copyright (C) 2009 Jose Luis Falcón Ramírez  jose.falconra@alum.uca.es
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###############################################################################*/

#ifndef _PERFILES_H
#define	_PERFILES_H

#define NUMJUEGOS 10         //Constante que controla el numero de juegos en OpenBTrainer, contando con Arcade

class perfiles {
public:
    /** Constructor de la clase perfiles
     * Crea, si no existe, el fichero de perifiles y carga los nombres de los perfiles.
     */
    perfiles();
    /** Función que se encarga de cargar un perfil que elegirá el usuario mediante la carga de una pantalla
     * que se encarga de esta tarea.
     * @param pantalla: Le pasaremos como parámetro la pantalla ya que tenemos que imprimir información en ella.
     */
    void cargar(SDL_Surface* pantalla);
    /** Procedimiento que nos ayudará a crear un nuevo perfil, también será capaz de captar el nombre del perfil
     * que el usuario le indique y crear y guardar la información en el fichero creado para tal.
     * @param pantalla: Le pasaremos como parámetro la pantalla ya que imprimimos la pantalla de introduccion de nombre de perfil.
     */
    void nuevoperfil(SDL_Surface* pantalla);
    /** Función que nos ayuda a actualizar la puntuación que tenemos almacenada en el fichero de perfil
     * Devuelve la puntuación mayor, es decir, la del perfil o la obtenida
     * @param perfil: Le pasaremos como parámetro el perfil activo.
     * @param numjuego: Le pasaremos el código del juego.
     * @param puntuacion: Le pasaremos la puntuación que ha obtenido el jugador.
     * @param tipopuntuacion: Le pasaremos el tipo de puntuación, si es tipo nivel, tiempo o puntos.
     * @param pantalla: Le pasaremos la variable pantalla ya que imprimiremos la pantalla que indica al usuario la puntuación que ha obtenido
     */
    Uint32 actualizarpuntuacion(Uint32 perfil, Uint32 numjuego, Uint32 puntuacion, Uint32 tipopuntuacion, SDL_Surface *pantalla);
    /** Función que devuelve el perfil activo*/
    Uint32 perfilactual();
    /** Procedimiento que nos ayuda a determinar el nombre del perfil activo
     * @param nombre: Le pasaremos un vector de caracteres para que introduzca en él el nombre del perfil.
     */
    void nombreperfilactual(char *nombre);
    /** Procedimiento que borra el perfil activo*/
    void borrarperfil();
    virtual ~perfiles();
private:
    void dibujarescenarioperfil(SDL_Surface* pantalla);
    void dibujarescenarioeditperfil(SDL_Surface* pantalla);
    char nombperfiles[4][21];
    Uint32 perfilactivo;
};

#endif	/* _PERFILES_H */

